@@ -121,6 +121,9 @@ ghex_window_close(GHexWindow *win)
 		gtk_widget_set_sensitive(converter_get, FALSE);
 
     gtk_widget_destroy(GTK_WIDGET(win));
+
+    if (doc->views == NULL) /* If we have destroyed the last view */
+      g_object_unref (G_OBJECT (doc));
 }
 
 static gboolean 
@@ -485,11 +488,25 @@ ghex_window_new(void)
 	return GTK_WIDGET(win);
 }
 
+static GtkWidget *
+create_document_view(HexDocument *doc)
+{
+    GtkWidget *gh = hex_document_add_view(doc);
+
+	gtk_hex_set_group_type(GTK_HEX(gh), def_group_type);
+
+	if (def_metrics && def_font_desc) {
+		gtk_hex_set_font(GTK_HEX(gh), def_metrics, def_font_desc);
+	}
+
+    return gh;
+}
+
 GtkWidget *
 ghex_window_new_from_doc(HexDocument *doc)
 {
     GtkWidget *win = ghex_window_new();
-    GtkWidget *gh = hex_document_add_view(doc);
+    GtkWidget *gh = create_document_view(doc);
 
     gtk_widget_show(gh);
     GHEX_WINDOW(win)->gh = GTK_HEX(gh);
@@ -586,7 +603,8 @@ ghex_window_load(GHexWindow *win, const gchar *filename)
     g_free(full_path);
     if(!doc)
         return FALSE;
-    gh = hex_document_add_view(doc);
+    hex_document_set_max_undo(doc, max_undo_depth);
+    gh = create_document_view(doc);
     gtk_hex_show_offsets(GTK_HEX(gh), show_offsets_column);
     g_signal_connect(G_OBJECT(doc), "document_changed",
                      G_CALLBACK(ghex_window_doc_changed), win);
@@ -912,6 +930,8 @@ ghex_window_save_as(GHexWindow *win)
 	HexDocument *doc;
 	GtkWidget *file_sel;
 	gboolean resp, ret_val = TRUE;
+	const gchar *filename;
+	gboolean dir_flag = FALSE;
 
 	if(win->gh == NULL)
 		return ret_val;
@@ -938,11 +958,32 @@ ghex_window_save_as(GHexWindow *win)
 	gtk_window_position (GTK_WINDOW (file_sel), GTK_WIN_POS_MOUSE);
 	gtk_widget_show (file_sel);
 
-	gtk_main();
+	do {
+		gtk_main();
+		filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(file_sel));
+		if (g_file_test(filename,G_FILE_TEST_IS_DIR)) {
+			gint name_len;
+			gchar *dir_name;
+
+			name_len = strlen (filename);
+			if (name_len < 1 || filename [name_len - 1] != '/')	{
+				dir_name = g_strconcat (filename, "/", NULL);
+			} else  {
+				dir_name = g_strdup (filename);
+			}
+			gtk_file_selection_set_filename (file_sel, dir_name);
+			g_free (dir_name);
+			dir_flag = TRUE;
+		}
+		else  {
+	     dir_flag = FALSE;
+		}
+	} while (resp && dir_flag);	   
+
+
 
 	if(resp) {
 		FILE *file;
-		const gchar *filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(file_sel));
 		gchar *flash;
 		int i;
         gint save = 0;
@@ -962,6 +1003,9 @@ ghex_window_save_as(GHexWindow *win)
                                                            GNOME_STOCK_BUTTON_YES,
                                                            GNOME_STOCK_BUTTON_NO,
                                                            NULL));
+			 gtk_window_set_type_hint (GTK_WINDOW (mbox), GDK_WINDOW_TYPE_HINT_DIALOG);
+			 gtk_window_set_transient_for (GTK_WINDOW (mbox), GTK_WINDOW (file_sel));
+
             g_free(msg);
             ret_val = (ask_user(mbox) == 0);
         }
@@ -1009,12 +1053,28 @@ ghex_window_save_as(GHexWindow *win)
 	return ret_val;
 }
 
+gboolean
+ghex_window_uri_exists (const gchar* text_uri)
+{
+	GnomeVFSURI *uri;
+	gboolean res;
+
+	g_return_val_if_fail (text_uri != NULL, FALSE);
+	uri = gnome_vfs_uri_new (text_uri);
+	g_return_val_if_fail (uri != NULL, FALSE);
+	res = gnome_vfs_uri_exists (uri);
+
+	gnome_vfs_uri_unref (uri);
+	return res;
+}
+
 gboolean
 ghex_window_ok_to_close(GHexWindow *win)
 {
 	static char msg[MESSAGE_LEN + 1];
 	GtkWidget *mbox;
 	gint reply;
+	gboolean uri_exists;
 	GtkWidget *save_btn;
     HexDocument *doc;
 
@@ -1022,8 +1082,8 @@ ghex_window_ok_to_close(GHexWindow *win)
         return TRUE;
 
     doc = win->gh->document;
-
-    if(!hex_document_has_changed(doc))
+    uri_exists = ghex_window_uri_exists(doc->file_name);
+    if(!hex_document_has_changed(doc) && uri_exists)
         return TRUE;
 
 	g_snprintf(msg, MESSAGE_LEN,
@@ -1050,7 +1110,7 @@ ghex_window_ok_to_close(GHexWindow *win)
 	gtk_widget_destroy(mbox);
 		
 	if(reply == GTK_RESPONSE_YES) {
-		if(doc->file_name == NULL) {
+		if(!uri_exists) {
 			if(!ghex_window_save_as(win)) {
 				return FALSE;
 			}
