@@ -22,28 +22,35 @@
  */
 
 #include <config.h>
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <gtkhex.h>
+#include <ghex-marshal.h>
 #include <gnome.h>
 
-#include "ghex.h"
-#include "gtkhex.h"
-
 #include <stdio.h>
+#include <unistd.h>
 #include <sys/stat.h>
 #include <string.h>
 
-static void hex_document_class_init        (HexDocumentClass *);
-static void hex_document_init              (HexDocument *doc);
-static void hex_document_finalize          (GObject *obj);
-static void hex_document_real_changed      (HexDocument *doc, gpointer change_data, gboolean undoable);
-static void move_gap_to (HexDocument *doc, guint offset, gint min_size);
-static void free_stack(GList *stack);
-static gint undo_stack_push(HexDocument *doc, HexChangeData *change_data);
-static void undo_stack_descend(HexDocument *doc);
-static void undo_stack_ascend(HexDocument *doc);
-static void undo_stack_free(HexDocument *doc);
-static gboolean get_document_attributes(HexDocument *doc);
+static void hex_document_class_init     (HexDocumentClass *);
+static void hex_document_init           (HexDocument *doc);
+static void hex_document_finalize       (GObject *obj);
+static void hex_document_real_changed   (HexDocument *doc,
+										 gpointer change_data,
+										 gboolean undoable);
+static void move_gap_to                 (HexDocument *doc,
+										 guint offset,
+								  	     gint min_size);
+static void free_stack                  (GList *stack);
+static gint undo_stack_push             (HexDocument *doc,
+									     HexChangeData *change_data);
+static void undo_stack_descend          (HexDocument *doc);
+static void undo_stack_ascend           (HexDocument *doc);
+static void undo_stack_free             (HexDocument *doc);
+static gboolean get_document_attributes (HexDocument *doc);
+
+#define DEFAULT_UNDO_DEPTH 1024
 
 enum {
 	DOCUMENT_CHANGED,
@@ -78,7 +85,7 @@ undo_stack_push(HexDocument *doc, HexChangeData *change_data)
 	HexChangeData *cd;
 	GList *stack_rest;
 
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 	g_message("undo_stack_push");
 #endif
 
@@ -101,14 +108,14 @@ undo_stack_push(HexDocument *doc, HexChangeData *change_data)
 
 		doc->undo_depth++;
 
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 		g_message("depth at: %d", doc->undo_depth);
 #endif
 
 		if(doc->undo_depth > doc->undo_max) {
 			GList *last;
 
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 			g_message("forget last undo");
 #endif
 
@@ -134,7 +141,7 @@ undo_stack_push(HexDocument *doc, HexChangeData *change_data)
 static void
 undo_stack_descend(HexDocument *doc)
 {
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 	g_message("undo_stack_descend");
 #endif
 
@@ -144,7 +151,7 @@ undo_stack_descend(HexDocument *doc)
 	doc->undo_top = doc->undo_top->next;
 	doc->undo_depth--;
 
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 	g_message("undo depth at: %d", doc->undo_depth);
 #endif
 
@@ -155,7 +162,7 @@ undo_stack_descend(HexDocument *doc)
 static void
 undo_stack_ascend(HexDocument *doc)
 {
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 	g_message("undo_stack_ascend");
 #endif
 
@@ -175,7 +182,7 @@ undo_stack_ascend(HexDocument *doc)
 static void
 undo_stack_free(HexDocument *doc)
 {
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
 	g_message("undo_stack_free");
 #endif
 
@@ -261,11 +268,6 @@ hex_document_add_view(HexDocument *doc)
 	new_view = gtk_hex_new(doc);
 
 	gtk_fixed_set_has_window (GTK_FIXED(new_view), TRUE);
-	gtk_hex_set_group_type(GTK_HEX(new_view), def_group_type);
-
-	if (def_metrics && def_font_desc) {
-		gtk_hex_set_font(GTK_HEX(new_view), def_metrics, def_font_desc);
-	}
 
 	gtk_widget_ref(new_view);
 
@@ -298,6 +300,9 @@ hex_document_finalize(GObject *obj)
 	if(hex->file_name)
 		g_free(hex->file_name);
 
+	if(hex->path_end)
+		g_free(hex->path_end);
+
 	undo_stack_free(hex);
 
 	while(hex->views)
@@ -359,7 +364,7 @@ hex_document_init (HexDocument *doc)
 	doc->undo_stack = NULL;
 	doc->undo_top = NULL;
 	doc->undo_depth = 0;
-	doc->undo_max = max_undo_depth;
+	doc->undo_max = DEFAULT_UNDO_DEPTH;
 }
 
 GType
@@ -397,7 +402,7 @@ HexDocument *
 hex_document_new(const gchar *name)
 {
 	HexDocument *doc;
-	
+	gchar *path_end;
 	int i;
 
 	doc = HEX_DOCUMENT (g_object_new (hex_document_get_type(), NULL));
@@ -413,10 +418,11 @@ hex_document_new(const gchar *name)
 		for(i = strlen(doc->file_name); (i >= 0) && (doc->file_name[i] != '/'); i--)
 			;
 		if(doc->file_name[i] == '/')
-			doc->path_end = &doc->file_name[i+1];
+			path_end = &doc->file_name[i+1];
 		else
-			doc->path_end = doc->file_name;
-					
+			path_end = doc->file_name;
+
+		doc->path_end = g_filename_to_utf8 (path_end, -1, NULL, NULL, NULL);
 		if(hex_document_read(doc)) {
 			doc_list = g_list_append(doc_list, doc);
 			return doc;
@@ -744,7 +750,7 @@ hex_document_export_html(HexDocument *doc, gchar *html_path, gchar *base_name,
 	fprintf(file, "</TABLE>\n</CENTER>\n");
 	fprintf(file, "<HR WIDTH=\"100%%\">");
 	fprintf(file, _("Hex dump generated by"));
-	fprintf(file, " <A HREF=\""GHEX_URL"\">GHex</A> "VERSION"\n");
+	fprintf(file, " <B>"LIBGTKHEX_RELEASE_STRING"</B>\n");
 	fprintf(file, "</BODY>\n</HTML>\n");
 	fclose(file);
 
@@ -869,7 +875,7 @@ hex_document_export_html(HexDocument *doc, gchar *html_path, gchar *base_name,
 		fprintf(file, "</TABLE>\n</CENTER>\n");
 		fprintf(file, "<HR WIDTH=\"100%%\">");
 		fprintf(file, _("Hex dump generated by"));
-		fprintf(file, " <A HREF=\""GHEX_URL"\">GHex</A> "VERSION"\n");
+		fprintf(file, " <B>"LIBGTKHEX_RELEASE_STRING"</B>\n");
 		fprintf(file, "</BODY>\n</HTML>\n");
 		fclose(file);
 	}
