@@ -26,10 +26,7 @@
 
 #include <stdio.h>
 
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
-
-#include <gnome.h>
+#include <glib-object.h>
 
 #define HEX_DOCUMENT_TYPE          (hex_document_get_type())
 #define HEX_DOCUMENT(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, hex_document_get_type (), HexDocument)
@@ -122,5 +119,6 @@ void        hex_document_set_menu_sensitivity(HexDocument *doc);
 void        hex_document_remove_view(HexDocument *doc, GtkWidget *view);
 GtkWidget   *hex_document_add_view(HexDocument *doc);
 const GList *hex_document_get_list(void);
+gboolean    hex_document_is_writable(HexDocument *doc);
 
 #endif /* __HEX_DOCUMENT_H__ */
