@@ -83,12 +83,14 @@ main(int argc, char **argv)
 	while(cl_files && *cl_files) {
 		if (g_file_exists (*cl_files)) {
 			win = ghex_window_new_from_file(*cl_files);
-			if(geometry) {
-				if(!gtk_window_parse_geometry(GTK_WINDOW(win), geometry))
-					g_warning(_("Invalid geometry string \"%s\"\n"), geometry);
+			if(win != NULL) {
+				if(geometry) {
+					if(!gtk_window_parse_geometry(GTK_WINDOW(win), geometry))
+						g_warning(_("Invalid geometry string \"%s\"\n"), geometry);
 					geometry = NULL;
+				}
+				gtk_widget_show(win);
 			}
-			gtk_widget_show(win);
 		}
 		cl_files++;
 	}
@@ -105,7 +107,6 @@ main(int argc, char **argv)
 	}
 	else win = GTK_WIDGET(ghex_window_get_list()->data);
 
-
 	bonobo_main();
 
 	return 0;
